@@ -4,6 +4,8 @@ use std::path::Path;
 
 use crate::android::config::Android;
 use crate::ios::config::Ios;
+use crate::jar::config::Jar;
+use crate::mac::config::Mac;
 
 ///
 /// Configuration struct mapping from Rsbind.toml
@@ -12,6 +14,8 @@ use crate::ios::config::Ios;
 pub struct Config {
     pub android: Option<Android>,
     pub ios: Option<Ios>,
+    pub mac: Option<Mac>,
+    pub jar: Option<Jar>,
 }
 
 ///
